.. _contributing:

Contributing to semver
======================

The semver source code is managed using Git and is hosted on GitHub::

   git clone git://github.com/python-semver/python-semver



Reporting Bugs and Asking Questions
-----------------------------------

If you think you have encountered a bug in semver or have an idea for a new
feature? Great! We like to hear from you!

There are several options to participate:

* Open a new topic on our `GitHub discussion <gh_discussions>`_ page.
  Tell us our ideas or ask your questions.

* Look into our GitHub `issues`_ tracker or open a new issue.


Prerequisites
-------------

Before you make changes to the code, we would highly appreciate if you
consider the following general requirements:

* Make sure your code adheres to the `Semantic Versioning`_ specification.

* Check if your feature is covered by the Semantic Versioning specification.
  If not, ask on its GitHub project https://github.com/semver/semver.


More topics
-----------

* `Running the Test Suite <docs/contribute/run-test-suite.rst>`_
* `Documenting semver <docs/contribute/doc-semver.rst>`_
* `Adding a Changelog Entry <docs/contribute/add-changelog-entry.rst>`_
* `Preparing the Release <docs/contribute/release-procedure.rst>`_
* `Finish the Release <docs/contribute/finish-release.rst>`_


.. _black: https://black.rtfd.io
.. _docformatter: https://pypi.org/project/docformatter/
.. _flake8: https://flake8.rtfd.io
.. _mypy: http://mypy-lang.org/
.. _issues:  https://github.com/python-semver/python-semver/issues
.. _pull request: https://github.com/python-semver/python-semver/pulls
.. _pytest: http://pytest.org/
.. _Semantic Versioning: https://semver.org
.. _Sphinx style: https://sphinx-rtd-tutorial.rtfd.io/en/latest/docstrings.html
.. _tox: https://tox.rtfd.org/
.. _gh_discussions: https://github.com/python-semver/python-semver/discussions
